@@ -16,18 +16,26 @@ use 5.00503;    # Galapagos Consensus 1998 for primetools
 # of ISBN 0-596-00313-7 Perl Cookbook, 2nd Edition.
 # (and so on)
 
+# Version numbers should be boring
+# http://www.dagolden.com/index.php/369/version-numbers-should-be-boring/
+# For the impatient, the disinterested or those who just want to follow
+# a recipe, my advice for all modules is this:
+# our $VERSION = "0.001"; # or "0.001_001" for a dev release
+# $VERSION = CORE::eval $VERSION;
+
 BEGIN { CORE::eval q{ use vars qw($VERSION) } }
-$VERSION = sprintf '%d.%02d', q$Revision: 1.02 $ =~ /(\d+)/oxmsg;
+$VERSION = '1.05';
+$VERSION = CORE::eval $VERSION;
 
 BEGIN {
     if ($^X =~ / jperl /oxmsi) {
-        die __FILE__, ": needs perl(not jperl) 5.00503 or later. (\$^X==$^X)";
+        die __FILE__, ": needs perl(not jperl) 5.00503 or later. (\$^X==$^X)\n";
     }
     if (CORE::ord('A') == 193) {
-        die __FILE__, ": is not US-ASCII script (may be EBCDIC or EBCDIK script).";
+        die __FILE__, ": is not US-ASCII script (may be EBCDIC or EBCDIK script).\n";
     }
     if (CORE::ord('A') != 0x41) {
-        die __FILE__, ": is not US-ASCII script (must be US-ASCII script).";
+        die __FILE__, ": is not US-ASCII script (must be US-ASCII script).\n";
     }
 }
 
@@ -90,8 +98,8 @@ sub EUCJP::escape_script;
 # (and so on)
 
 # regexp of character
-my $qq_char   = qr/\\c[\x40-\x5F]|\\?(?:\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[\x00-\xFF])/oxms;
-my  $q_char   = qr/\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[\x00-\xFF]/oxms;
+my $qq_char   = qr/(?> \\c[\x40-\x5F] | \\? (?:[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF] | [\x00-\xFF]) )/oxms;
+my  $q_char   = qr/(?> [\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF] | [\x00-\xFF] )/oxms;
 
 # when this script is main program
 if ($0 eq __FILE__) {
@@ -190,12 +198,18 @@ sub import {
         if (CORE::eval q{ use Fcntl qw(O_WRONLY O_APPEND O_CREAT); 1 } and CORE::sysopen($fh,"$filename.e",&O_WRONLY|&O_APPEND|&O_CREAT)) {
         }
         else {
-            Eeucjp::_open_a($fh, "$filename.e") or die __FILE__, ": Can't write open file: $filename.e";
+            Eeucjp::_open_a($fh, "$filename.e") or die __FILE__, ": Can't write open file: $filename.e\n";
         }
 
+        # 7.19. Flushing Output
+        # in Chapter 7. File Access
+        # of ISBN 0-596-00313-7 Perl Cookbook, 2nd Edition.
+
+        select((select($fh), $|=1)[0]);
+
         if (0) {
         }
-        elsif (exists $ENV{'SJIS_NONBLOCK'}) {
+        elsif (exists $ENV{'CHAR_NONBLOCK'}) {
 
             # P.419 File Locking
             # in Chapter 16: Interprocess Communication
@@ -215,19 +229,17 @@ sub import {
 
             # (and so on)
 
-            CORE::eval q{
-                unless (flock($fh, LOCK_EX | LOCK_NB)) {
-                    warn __FILE__, ": Can't immediately write-lock the file: $filename.e";
-                    exit;
-                }
-            };
+            CORE::eval q{ flock($fh, LOCK_EX | LOCK_NB) };
+            if ($@) {
+                die __FILE__, ": Can't immediately write-lock the file: $filename.e\n";
+            }
         }
         else {
             CORE::eval q{ flock($fh, LOCK_EX) };
         }
 
         CORE::eval q{ truncate($fh, 0) };
-        seek($fh, 0, 0) or die __FILE__, ": Can't seek file: $filename.e";
+        seek($fh, 0, 0) or die __FILE__, ": Can't seek file: $filename.e\n";
 
         my $e_script = EUCJP::escape_script($filename);
         print {$fh} $e_script;
@@ -235,21 +247,19 @@ sub import {
         my $mode = (stat($filename))[2] & 0777;
         chmod $mode, "$filename.e";
 
-        close($fh) or die __FILE__, ": Can't close file: $filename.e";
+        close($fh) or die __FILE__, ": Can't close file: $filename.e\n";
     }
 
     my $fh = gensym();
-    Eeucjp::_open_r($fh, "$filename.e") or die __FILE__, ": Can't read open file: $filename.e";
+    Eeucjp::_open_r($fh, "$filename.e") or die __FILE__, ": Can't read open file: $filename.e\n";
 
     if (0) {
     }
-    elsif (exists $ENV{'SJIS_NONBLOCK'}) {
-        CORE::eval q{
-            unless (flock($fh, LOCK_SH | LOCK_NB)) {
-                warn __FILE__, ": Can't immediately read-lock the file: $filename.e";
-                exit;
-            }
-        };
+    elsif (exists $ENV{'CHAR_NONBLOCK'}) {
+        CORE::eval q{ flock($fh, LOCK_SH | LOCK_NB) };
+        if ($@) {
+            die __FILE__, ": Can't immediately read-lock the file: $filename.e\n";
+        }
     }
     else {
         CORE::eval q{ flock($fh, LOCK_SH) };
@@ -259,6 +269,10 @@ sub import {
     if ($^W) {
         push @switch, '-w';
     }
+    if (defined $^I) {
+        push @switch, '-i' . $^I;
+        undef $^I;
+    }
 
     # P.707 29.2.33. exec
     # in Chapter 29: Functions
@@ -351,12 +365,12 @@ sub EUCJP::escape_script {
 
     # read EUC-JP script
     my $fh = gensym();
-    Eeucjp::_open_r($fh, $script) or die __FILE__, ": Can't open file: $script";
+    Eeucjp::_open_r($fh, $script) or die __FILE__, ": Can't open file: $script\n";
     local $/ = undef; # slurp mode
     $_ = <$fh>;
-    close($fh) or die __FILE__, ": Can't close file: $script";
+    close($fh) or die __FILE__, ": Can't close file: $script\n";
 
-    if (/^ use Eeucjp(?:\s+[0-9\.]*)?\s*; $/oxms) {
+    if (/^ use Eeucjp(?:(?>\s+)(?>[0-9\.]*))?(?>\s*); $/oxms) {
         return $_;
     }
     else {
@@ -369,7 +383,7 @@ sub EUCJP::escape_script {
         }
 
         # DOS-like system header
-        if (s/\A(\@rem\s*=\s*'.*?'\s*;\s*\n)//oms) {
+        if (s/\A(\@rem(?>\s*)=(?>\s*)'.*?'(?>\s*);\s*\n)//oms) {
             my $head = $1;
             $head =~ s/\bjperl\b/perl/gi;
             $e_script .= $head;
@@ -383,7 +397,7 @@ sub EUCJP::escape_script {
         # in Chapter 21: Common Practices
         # of ISBN 978-0-596-00492-7 Programming Perl 4th Edition.
 
-        if (s/(.*^#\s*line\s+\d+(?:\s+"(?:$q_char)+?")?\s*\n)//oms) {
+        if (s/(.*^#(?>\s*)line(?>\s+)(?>[0-9]+)(?:(?>\s+)"(?:$q_char)+?")?\s*\n)//oms) {
             my $head = $1;
             $head =~ s/\bjperl\b/perl/gi;
             $e_script .= $head;
@@ -402,11 +416,11 @@ sub EUCJP::escape_script {
         $e_script .= sprintf("use Eeucjp '%s.0'; # 'quote' for perl5.6\n", $EUCJP::VERSION); # require run-time routines version
 
         # use EUCJP version qw(ord reverse getc);
-        if (s/^ \s* use \s+ EUCJP \s* ([^\x8E\x8F\xA1-\xFE;]*) ; \s* \n? $//oxms) {
+        if (s/^ (?>\s*) use (?>\s+) (?: Char | EUCJP ) (?>\s*) ([^\x8E\x8F\xA1-\xFE;]*) ; \s* \n? $//oxms) {
 
             # require version
             my $list = $1;
-            if ($list =~ s/\A ([0-9]+\.[0-9]+) \.0 \s* //oxms) {
+            if ($list =~ s/\A ((?>[0-9]+)\.(?>[0-9]+)) \.0 (?>\s*) //oxms) {
                 my $version = $1;
                 if ($version ne $EUCJP::VERSION) {
                     my @file = grep -e, map {qq{$_/EUCJP.pm}} @INC;
@@ -428,7 +442,7 @@ END
                 }
                 $e_script .= qq{die "Script \$0 expects Eeucjp.pm $version, but \\\$Eeucjp::VERSION is \$Eeucjp::VERSION" if \$Eeucjp::VERSION ne '$version';\n};
             }
-            elsif ($list =~ s/\A ([0-9]+(?:\.[0-9]*)) \s* //oxms) {
+            elsif ($list =~ s/\A ((?>[0-9]+)(?>\.[0-9]*)) (?>\s*) //oxms) {
                 my $version = $1;
                 if ($version > $EUCJP::VERSION) {
                     die "Script $0 required EUCJP.pm $version, but @{[__FILE__]} is only version $EUCJP::VERSION\n";
@@ -436,7 +450,7 @@ END
             }
 
             # demand ord, reverse, and getc
-            if ($list !~ /\A \s* \z/oxms) {
+            if ($list !~ /\A (?>\s*) \z/oxms) {
                 local $@;
                 my @list = CORE::eval $list;
                 for (@list) {
@@ -711,11 +725,11 @@ It means incompatible upgrade of Perl should be rewound.
 
 You need write 'use EUCJP;' in your script.
 
-  ---------------------------------
-  Before      You do
-  ---------------------------------
-  (nothing)   use EUCJP;
-  ---------------------------------
+  ---------------------
+  You do
+  ---------------------
+  use EUCJP;
+  ---------------------
 
 =head1 Multiple-Octet Anchoring of Regular Expression (EUCJP software provides)
 
@@ -882,42 +896,48 @@ Definitions in Eeucjp.pm.
   ---------------------------------------------------------------------------------------------------------------------------------------------------------
   After                    Definition
   ---------------------------------------------------------------------------------------------------------------------------------------------------------
-  ${Eeucjp::anchor}         qr{\G(?:\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[^\x8E\x8F\xA1-\xFE])*?}
+  ${Eeucjp::anchor}         qr{\G(?>[^\x8E\x8F\xA1-\xFE]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])*?}
                            for over 32766 octets string on ActivePerl5.6 and Perl5.10 or later
-                           qr{\G(?(?=.{0,32766}\z)(?:\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[^\x8E\x8F\xA1-\xFE])*?|(?(?=[$sbcs]+\z).*?|(?:.*?[$sbcs](?:$tbcs_1st[^$sbcs]{2})*?)))}oxms;
-  ${Eeucjp::dot}            qr{(?:\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[^\x8E\x8F\xA1-\xFE\x0A])}
-  ${Eeucjp::dot_s}          qr{(?:\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[^\x8E\x8F\xA1-\xFE])}
-  ${Eeucjp::eD}             qr{(?:\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[^\x8E\x8F\xA1-\xFE0-9])}
-  ${Eeucjp::eS}             qr{(?:\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[^\x8E\x8F\xA1-\xFE\s])}
-  ${Eeucjp::eW}             qr{(?:\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[^\x8E\x8F\xA1-\xFE0-9A-Z_a-z])}
-  ${Eeucjp::eH}             qr{(?:\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[^\x8E\x8F\xA1-\xFE\x09\x20])}
-  ${Eeucjp::eV}             qr{(?:\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[^\x8E\x8F\xA1-\xFE\x0A\x0B\x0C\x0D])}
-  ${Eeucjp::eR}             qr{(?:\x0D\x0A|[\x0A\x0D])}
-  ${Eeucjp::eN}             qr{(?:\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[^\x8E\x8F\xA1-\xFE\x0A])}
-  ${Eeucjp::not_alnum}      qr{(?:\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[^\x8E\x8F\xA1-\xFE\x30-\x39\x41-\x5A\x61-\x7A])}
-  ${Eeucjp::not_alpha}      qr{(?:\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[^\x8E\x8F\xA1-\xFE\x41-\x5A\x61-\x7A])}
-  ${Eeucjp::not_ascii}      qr{(?:\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[^\x8E\x8F\xA1-\xFE\x00-\x7F])}
-  ${Eeucjp::not_blank}      qr{(?:\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[^\x8E\x8F\xA1-\xFE\x09\x20])}
-  ${Eeucjp::not_cntrl}      qr{(?:\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[^\x8E\x8F\xA1-\xFE\x00-\x1F\x7F])}
-  ${Eeucjp::not_digit}      qr{(?:\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[^\x8E\x8F\xA1-\xFE\x30-\x39])}
-  ${Eeucjp::not_graph}      qr{(?:\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[^\x8E\x8F\xA1-\xFE\x21-\x7F])}
-  ${Eeucjp::not_lower}      qr{(?:\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[^\x8E\x8F\xA1-\xFE\x61-\x7A])}
-  ${Eeucjp::not_lower_i}    qr{(?:\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[^\x8E\x8F\xA1-\xFE])}
-  ${Eeucjp::not_print}      qr{(?:\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[^\x8E\x8F\xA1-\xFE\x20-\x7F])}
-  ${Eeucjp::not_punct}      qr{(?:\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[^\x8E\x8F\xA1-\xFE\x21-\x2F\x3A-\x3F\x40\x5B-\x5F\x60\x7B-\x7E])}
-  ${Eeucjp::not_space}      qr{(?:\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[^\x8E\x8F\xA1-\xFE\s\x0B])}
-  ${Eeucjp::not_upper}      qr{(?:\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[^\x8E\x8F\xA1-\xFE\x41-\x5A])}
-  ${Eeucjp::not_upper_i}    qr{(?:\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[^\x8E\x8F\xA1-\xFE])}
-  ${Eeucjp::not_word}       qr{(?:\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[^\x8E\x8F\xA1-\xFE\x30-\x39\x41-\x5A\x5F\x61-\x7A])}
-  ${Eeucjp::not_xdigit}     qr{(?:\x8F[\xA1-\xFE][\xA1-\xFE]|[\x8E\xA1-\xFE][\x00-\xFF]|[^\x8E\x8F\xA1-\xFE\x30-\x39\x41-\x46\x61-\x66])}
-  ${Eeucjp::eb}             qr{(?:\A(?=[0-9A-Z_a-z])|(?<=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF])(?=[0-9A-Z_a-z])|(?<=[0-9A-Z_a-z])(?=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF]|\z))}
-  ${Eeucjp::eB}             qr{(?:(?<=[0-9A-Z_a-z])(?=[0-9A-Z_a-z])|(?<=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF])(?=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF]))}
+                           qr{\G(?(?=.{0,32766}\z)\G(?>[^\x8E\x8F\xA1-\xFE]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])*?|(?(?=[\x00-\x8D\x90-\xA0\xFF]+\z).*?|(?:.*?[^\x8E\x8F\xA1-\xFE](?>[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\xA1-\xFE])*?)))}oxms
+                           for over 32766 octets string on ActivePerl5.6 and Perl5.10 or later
+                           qr{\G(?(?=.{0,32766}\z)\G(?>[^\x8E\x8F\xA1-\xFE]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])*?|(?(?=[$sbcs]+\z).*?|(?:.*?[$sbcs](?:[^$sbcs][^$sbcs])*?)))}oxms
+  ${Eeucjp::dot}            qr{(?>[^\x8E\x8F\xA1-\xFE\x0A]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])};
+  ${Eeucjp::dot_s}          qr{(?>[^\x8E\x8F\xA1-\xFE]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])};
+  ${Eeucjp::eD}             qr{(?>[^\x8E\x8F\xA1-\xFE0-9]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])};
+  ${Eeucjp::eS}             qr{(?>[^\x8E\x8F\xA1-\xFE\s]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])};
+  ${Eeucjp::eW}             qr{(?>[^\x8E\x8F\xA1-\xFE0-9A-Z_a-z]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])};
+  ${Eeucjp::eH}             qr{(?>[^\x8E\x8F\xA1-\xFE\x09\x20]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])};
+  ${Eeucjp::eV}             qr{(?>[^\x8E\x8F\xA1-\xFE\x0A\x0B\x0C\x0D]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])};
+  ${Eeucjp::eR}             qr{(?>\x0D\x0A|[\x0A\x0D])};
+  ${Eeucjp::eN}             qr{(?>[^\x8E\x8F\xA1-\xFE\x0A]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])};
+  ${Eeucjp::not_alnum}      qr{(?>[^\x8E\x8F\xA1-\xFE\x30-\x39\x41-\x5A\x61-\x7A]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])};
+  ${Eeucjp::not_alpha}      qr{(?>[^\x8E\x8F\xA1-\xFE\x41-\x5A\x61-\x7A]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])};
+  ${Eeucjp::not_ascii}      qr{(?>[^\x8E\x8F\xA1-\xFE\x00-\x7F]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])};
+  ${Eeucjp::not_blank}      qr{(?>[^\x8E\x8F\xA1-\xFE\x09\x20]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])};
+  ${Eeucjp::not_cntrl}      qr{(?>[^\x8E\x8F\xA1-\xFE\x00-\x1F\x7F]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])};
+  ${Eeucjp::not_digit}      qr{(?>[^\x8E\x8F\xA1-\xFE\x30-\x39]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])};
+  ${Eeucjp::not_graph}      qr{(?>[^\x8E\x8F\xA1-\xFE\x21-\x7F]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])};
+  ${Eeucjp::not_lower}      qr{(?>[^\x8E\x8F\xA1-\xFE\x61-\x7A]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])};
+  ${Eeucjp::not_lower_i}    qr{(?>[^\x8E\x8F\xA1-\xFE\x41-\x5A\x61-\x7A]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])}; # Perl 5.16 compatible
+# ${Eeucjp::not_lower_i}    qr{(?>[^\x8E\x8F\xA1-\xFE]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])};                   # older Perl compatible
+  ${Eeucjp::not_print}      qr{(?>[^\x8E\x8F\xA1-\xFE\x20-\x7F]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])};
+  ${Eeucjp::not_punct}      qr{(?>[^\x8E\x8F\xA1-\xFE\x21-\x2F\x3A-\x3F\x40\x5B-\x5F\x60\x7B-\x7E]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])};
+  ${Eeucjp::not_space}      qr{(?>[^\x8E\x8F\xA1-\xFE\s\x0B]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])};
+  ${Eeucjp::not_upper}      qr{(?>[^\x8E\x8F\xA1-\xFE\x41-\x5A]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])};
+  ${Eeucjp::not_upper_i}    qr{(?>[^\x8E\x8F\xA1-\xFE\x41-\x5A\x61-\x7A]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])}; # Perl 5.16 compatible
+# ${Eeucjp::not_upper_i}    qr{(?>[^\x8E\x8F\xA1-\xFE]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])};                   # older Perl compatible
+  ${Eeucjp::not_word}       qr{(?>[^\x8E\x8F\xA1-\xFE\x30-\x39\x41-\x5A\x5F\x61-\x7A]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])};
+  ${Eeucjp::not_xdigit}     qr{(?>[^\x8E\x8F\xA1-\xFE\x30-\x39\x41-\x46\x61-\x66]|[\x8E\xA1-\xFE][\xA1-\xFE]|\x8F[\xA1-\xFE][\x00-\xFF])};
+  
+  # This solution is not perfect. I beg better solution from you who are reading this.
+  ${Eeucjp::eb}             qr{(?:\A(?=[0-9A-Z_a-z])|(?<=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF])(?=[0-9A-Z_a-z])|(?<=[0-9A-Z_a-z])(?=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF]|\z))};
+  ${Eeucjp::eB}             qr{(?:(?<=[0-9A-Z_a-z])(?=[0-9A-Z_a-z])|(?<=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF])(?=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF]))};
   ---------------------------------------------------------------------------------------------------------------------------------------------------------
 
-=head1 Un-Escaping \ of \N, \p, \P, and \X (EUCJP software provides)
+=head1 Un-Escaping \ of \b{}, \B{}, \N{}, \p{}, \P{}, and \X (EUCJP software provides)
 
-EUCJP software removes '\' at head of alphanumeric regexp metasymbols \N, \p, \P
-and \X. By this method, you can avoid the trap of the abstraction.
+EUCJP software removes '\' at head of alphanumeric regexp metasymbols \b{}, \B{},
+\N{}, \p{}, \P{} and \X. By this method, you can avoid the trap of the abstraction.
 
 See also,
 Deprecate literal unescaped "{" in regexes.
@@ -926,6 +946,8 @@ http://perl5.git.perl.org/perl.git/commit/2a53d3314d380af5ab5283758219417c6dfa36
   ------------------------------------
   Before           After
   ------------------------------------
+  \b{...}          b\{...}
+  \B{...}          B\{...}
   \N{CHARNAME}     N\{CHARNAME}
   \p{L}            p\{L}
   \p{^L}           p\{^L}
@@ -938,7 +960,7 @@ http://perl5.git.perl.org/perl.git/commit/2a53d3314d380af5ab5283758219417c6dfa36
   \X               X
   ------------------------------------
 
-=head1 Escaping Built-in Functions (EUCJP software provide)
+=head1 Escaping Built-in Functions (EUCJP software provides)
 
 Insert 'Eeucjp::' at head of function name. Eeucjp.pm provides your script Eeucjp::*
 subroutines.
@@ -994,6 +1016,7 @@ oriented subroutine. See 'Character-Oriented Subroutines'.
   substr     EUCJP::substr
   index      EUCJP::index          See 'About Indexes'
   rindex     EUCJP::rindex         See 'About Rindexes'
+  eval       EUCJP::eval
   --------------------------------------------------------
 
   About Indexes
@@ -1621,6 +1644,54 @@ oriented subroutine. See 'Character-Oriented Subroutines'.
 
 =back
 
+=head1 Yada Yada Operator (EUCJP software provides)
+
+  The yada yada operator (noted ...) is a placeholder for code. Perl parses it
+  without error, but when you try to execute a yada yada, it throws an exception
+  with the text Unimplemented:
+
+  sub unimplemented { ... }
+  eval { unimplemented() };
+  if ( $@ eq 'Unimplemented' ) {
+      print "I found the yada yada!\n";
+  }
+
+  You can only use the yada yada to stand in for a complete statement. These
+  examples of the yada yada work:
+
+  { ... }
+  sub foo { ... }
+  ...;
+  eval { ... };
+  sub foo {
+      my( $self ) = shift;
+      ...;
+  }
+  do { my $n; ...; print 'Hurrah!' };
+
+  The yada yada cannot stand in for an expression that is part of a larger statement
+  since the ... is also the three-dot version of the range operator
+  (see "Range Operators"). These examples of the yada yada are still syntax errors:
+
+  print ...;
+  open my($fh), '>', '/dev/passwd' or ...;
+  if ( $condition && ... ) { print "Hello\n" };
+
+  There are some cases where Perl can't immediately tell the difference between an
+  expression and a statement. For instance, the syntax for a block and an anonymous
+  hash reference constructor look the same unless there's something in the braces that
+  give Perl a hint. The yada yada is a syntax error if Perl doesn't guess that the
+  { ... } is a block. In that case, it doesn't think the ... is the yada yada because
+  it's expecting an expression instead of a statement:
+
+  my @transformed = map { ... } @input;  # syntax error
+
+  You can use a ; inside your block to denote that the { ... } is a block and not a
+  hash reference constructor. Now the yada yada works:
+
+  my @transformed = map {; ... } @input; # ; disambiguates
+  my @transformed = map { ...; } @input; # ; disambiguates
+
 =head1 Un-Escaping bytes::* Subroutines (EUCJP software provides)
 
 EUCJP software removes 'bytes::' at head of subroutine name.
@@ -1747,11 +1818,11 @@ EUCJP software removes 'bytes::' at head of subroutine name.
  This software uses the flock function for exclusive control. The execution of the
  program is blocked until it becomes possible to read or write the file.
  You can have it not block in the flock function by defining environment variable
- SJIS_NONBLOCK.
+ CHAR_NONBLOCK.
  
  Example:
  
-   SET SJIS_NONBLOCK=1
+   SET CHAR_NONBLOCK=1
  
  (The value '1' doesn't have the meaning)
 
@@ -1866,6 +1937,17 @@ support these.
 qq//, q//, qw//, qx//, qr//, m//, s///, tr///, and y/// can't use a wide character
 as the delimiter.
 
+=item * \b{...} Boundaries in Regular Expressions
+
+Following \b{...} available starting in v5.22 are not supported.
+
+  \b{gcb} or \b{g}   Unicode "Grapheme Cluster Boundary"
+  \b{sb}             Unicode "Sentence Boundary"
+  \b{wb}             Unicode "Word Boundary"
+  \B{gcb} or \B{g}   Unicode "Grapheme Cluster Boundary" doesn't match
+  \B{sb}             Unicode "Sentence Boundary" doesn't match
+  \B{wb}             Unicode "Word Boundary" doesn't match
+
 =back
 
 =head1 AUTHOR
@@ -1906,40 +1988,55 @@ consideration of the UTF8 flag.
     | Flagged  |            Flagged              |
     +--------------------------------------------+
     http://perl-users.jp/articles/advent-calendar/2010/casual/4
+
+  Confusion of Perl string model is made from double meanings of
+  "Binary string."
+  Meanings of "Binary string"
+  1. Non-Text string
+  2. Digital octet string
+
+  Let's draw again using those term.
  
-    (Why is only Latin-1 special?)
+    +----------------------+---------------------+
+    |     Text strings     |                     |
+    +----------+-----------|   Non-Text strings  |
+    |  UTF-8   |  Latin-1  |                     |
+    +----------+-----------+---------------------+
+    | UTF8     |            Not UTF8             |
+    | Flagged  |            Flagged              |
+    +--------------------------------------------+
+    |            Digital octet string            |
+    +--------------------------------------------+
 
-This change consequentially made a big gap between a past script and
-new script. Both scripts cannot re-use the code mutually any longer.
-Because a new method puts a strain in the programmer, it will still take
-time to replace all the in existence scripts.
-
-The biggest problem of new method is that the UTF8 flag can't synchronize
-to real encode of string. Thus you must debug about UTF8 flag, before
-your script. How to solve it by returning to a this method, let's drag out
+There are people who don't agree to change in the character string
+processing model of Perl 5.8. It is impossible to get to agree it to
+majority of Perl user who hardly ever use Perl.
+How to solve it by returning to a original method, let's drag out
 page 402 of the old dusty Programming Perl, 3rd ed. again.
 
-  Information processing model beginning with perl3 or this software of
-  UNIX/C-ism.
+  Information processing model beginning with perl3 or this software
+  of UNIX/C-ism.
 
     +--------------------------------------------+
-    |       Text strings as Binary strings       |
-    |       Binary strings as Text strings       |
+    |    Text string as Digital octet string     |
+    |    Digital octet string as Text string     |
     +--------------------------------------------+
-    |        Not UTF8 Flagged, UNIX/C-ism        |
+    |       Not UTF8 Flagged, No Mojibake        |
     +--------------------------------------------+
 
-  Script could be written in native encoding of operating systems.
-  - Like contents of a file
-  - Like a file name on the file systems
-  - Like command lines
-  - Like environment variables
-  - Like parameters of API
-
   In UNIX Everything is a File
   - In UNIX everything is a stream of bytes
   - In UNIX the filesystem is used as a universal name space
 
+  Native Encoding Scripting
+  - native encoding of file contents
+  - native encoding of file name on filesystem
+  - native encoding of command line
+  - native encoding of environment variable
+  - native encoding of API
+  - native encoding of network packet
+  - native encoding of database
+
 Ideally, I'd like to achieve these five Goals:
 
 =over 2
@@ -2043,7 +2140,7 @@ May the JPerl be with you, always.
 =back
 
 Back when Programming Perl, 3rd ed. was written, UTF8 flag was not born
-and Perl is designed to make the easy jobs easy. This software provide
+and Perl is designed to make the easy jobs easy. This software provides
 programming environment like at that time.
 
 =head1 Perl's motto
@@ -2223,6 +2320,12 @@ programming environment like at that time.
  ISBN 10:0-596-52068-9 | ISBN 13: 978-0-596-52068-7
  http://shop.oreilly.com/product/9780596520694.do
 
+ Regular Expressions Cookbook, 2nd Edition
+ By Jan Goyvaerts, Steven Levithan
+ Final Release Date: August 2012
+ Pages: 612
+ ISBN: 978-1-4493-1943-4 | ISBN 10:1-4493-1943-2
+
  JIS KANJI JITEN
  By Kouji Shibano
  Pages: 1456
@@ -2309,6 +2412,7 @@ I am thankful to all persons.
  http://www.perl.org/
 
  Kazumasa Utashiro, jcode.pl
+ http://search.cpan.org/~utashiro/
  ftp://ftp.iij.ad.jp/pub/IIJ/dist/utashiro/perl/
  http://log.utashiro.com/pub/2006/07/jkondo_a580.html
 
@@ -2415,5 +2519,3 @@ I am thankful to all persons.
  http://www.freeml.com/perl-oo/514
 
 =cut
-
-# Did you fun enough? ^o^)
